PluginContext

Struct PluginContext 

pub struct PluginContext {
    pub config: PluginConfigData,
    pub state: Arc<Mutex<PluginSharedState>>,
    pub logger_name: String,
    pub commands: Arc<Mutex<Vec<RemoteCommand>>>,
}
Context provided to plugins for interacting with the terminal

Fields

config: PluginConfigData

Plugin-specific configuration

state: Arc<Mutex<PluginSharedState>>

Shared terminal state

logger_name: String

Logger name for this plugin

commands: Arc<Mutex<Vec<RemoteCommand>>>

Queue of commands to be sent to the client/daemon

Implementations

Source

impl PluginContext

pub fn new( config: PluginConfigData, state: Arc<Mutex<PluginSharedState>>, logger_name: impl Into<String>, ) -> Self

Create new plugin context

pub fn queue_command(&self, cmd: RemoteCommand)

Queue a command to be sent to the client or daemon

pub fn get_cell(&self, x: u16, y: u16) -> Option<Cell>

Get cell at position

pub fn set_cell(&self, x: u16, y: u16, cell: Cell) -> bool

Set cell at position

pub fn get_line(&self, y: u16) -> Option<String>

Get line of text at row

pub fn get_size(&self) -> (u16, u16)

Get terminal size

pub fn get_cursor(&self) -> (u16, u16)

Get cursor position

pub fn get_env(&self, key: &str) -> Option<String>

Get environment variable

pub fn set_data(&self, key: impl Into<String>, value: impl Into<String>)

Store plugin-specific data

pub fn get_data(&self, key: &str) -> Option<String>

Retrieve plugin-specific data

pub fn log(&self, level: LogLevel, message: &str)

Log a message with the integrated logging system

Messages are sent to both the Rust logging infrastructure (using the log crate) and queued as a remote command to be forwarded to connected clients for display.

pub fn notify(&self, title: &str, body: &str, level: NotifyLevel)

Send a notification to the user

Notifications are displayed as UI overlays in the client with auto-dismiss after 5 seconds. The notification level determines the visual styling (color, icon, etc.).

pub fn notify_info(&self, title: &str, body: &str)

Convenience method to send an info notification

pub fn notify_success(&self, title: &str, body: &str)

Convenience method to send a success notification

pub fn notify_warning(&self, title: &str, body: &str)

Convenience method to send a warning notification

pub fn notify_error(&self, title: &str, body: &str)

Convenience method to send an error notification