Module delight

Module delight 

Delightful messages, ASCII art, and celebrations for the plugin system

Making plugin development and usage more enjoyable, one message at a time.

Enums

Achievement
Achievement system for plugin milestones
PluginMood
Plugin mood indicator based on performance

Constants

CONFETTI
ASCII art for celebrations
DEVELOPER_TIPS
Tips and tricks for plugin developers
ERROR_PREFIXES
Friendly error message prefixes
LOADING_MESSAGES
Loading messages to show when plugins are being loaded
PARTY_POPPER
ROCKET
SUCCESS_MESSAGES
Success messages for plugin loading
TROPHY

Functions

celebration_message
Format a celebration message for special occasions
friendly_error
Format a friendly error message with suggestions
random_developer_tip
Get a random developer tip
random_error_prefix
Get a random error prefix
random_loading_message
Get a random loading message
random_success_message
Get a random success message
special_date_message
Check if today is a special date and return a message