pub struct KeyTableActivation {
pub name: String,
pub table: KeyTable,
pub mode: ActivateKeyTableMode,
pub timeout: Option<Instant>,
pub replace_current: bool,
}Expand description
An activation of a key table on the stack
Fields
name: StringName of the activated table
table: KeyTableThe key table itself
mode: ActivateKeyTableModeActivation mode
timeout: Option<Instant>Optional timeout (absolute time when this activation expires)
replace_current: boolWhether this activation replaces the previous one
Implementations
Sourceimpl KeyTableActivation
impl KeyTableActivation
Sourcepub fn persistent(name: String, table: KeyTable) -> Self
pub fn persistent(name: String, table: KeyTable) -> Self
Create a new persistent activation
Sourcepub fn timed(
name: String,
table: KeyTable,
duration: Duration,
now: Instant,
) -> Self
pub fn timed( name: String, table: KeyTable, duration: Duration, now: Instant, ) -> Self
Create a new timed activation
Sourcepub fn with_replace(self, replace: bool) -> Self
pub fn with_replace(self, replace: bool) -> Self
Set whether this activation should replace the current one