pub enum ObjectError {
NotFound {
handle: ObjectHandle,
},
StaleHandle {
handle: ObjectHandle,
current_generation: u32,
},
TypeMismatch {
handle: ObjectHandle,
expected: ObjectType,
actual: ObjectType,
},
MethodNotFound {
handle: ObjectHandle,
method_name: String,
},
InvalidArgument {
handle: ObjectHandle,
method_name: String,
argument: String,
reason: String,
},
}Expand description
Errors that can occur when working with the object model
Variants
NotFound
The requested object was not found in the registry
Fields

handle: ObjectHandleStaleHandle
The handle refers to an object that has been deleted and recreated
TypeMismatch
The object exists but is not of the expected type
MethodNotFound
The requested method does not exist on this object type
InvalidArgument
Invalid argument passed to object method
Implementations
Sourceimpl ObjectError
impl ObjectError
Sourcepub fn not_found(handle: ObjectHandle) -> Self
pub fn not_found(handle: ObjectHandle) -> Self
Create a NotFound error
Sourcepub fn stale_handle(handle: ObjectHandle, current_generation: u32) -> Self
pub fn stale_handle(handle: ObjectHandle, current_generation: u32) -> Self
Create a StaleHandle error
Sourcepub fn type_mismatch(
handle: ObjectHandle,
expected: ObjectType,
actual: ObjectType,
) -> Self
pub fn type_mismatch( handle: ObjectHandle, expected: ObjectType, actual: ObjectType, ) -> Self
Create a TypeMismatch error
Sourcepub fn method_not_found(
handle: ObjectHandle,
method_name: impl Into<String>,
) -> Self
pub fn method_not_found( handle: ObjectHandle, method_name: impl Into<String>, ) -> Self
Create a MethodNotFound error
Sourcepub fn invalid_argument(
handle: ObjectHandle,
method_name: impl Into<String>,
argument: impl Into<String>,
reason: impl Into<String>,
) -> Self
pub fn invalid_argument( handle: ObjectHandle, method_name: impl Into<String>, argument: impl Into<String>, reason: impl Into<String>, ) -> Self
Create an InvalidArgument error