TabProxy

Struct TabProxy 

pub struct TabProxy { /* private fields */ }
Proxy for a terminal tab

Implementations

Source

impl TabProxy

pub fn new(handle: ObjectHandle) -> Result<Self>

pub fn handle(&self) -> ObjectHandle

pub fn id(&self) -> u64

pub fn get_title(&self) -> Result<String>

Get tab title

pub fn set_title(&self, _title: &str) -> Result<()>

Set tab title

pub fn panes<T>( &self, registry: &impl ObjectRegistry<T>, ) -> Result<Vec<PaneProxy>>

Get all panes in this tab

Arguments
  • registry - The object registry to use for navigation
Returns
  • Ok(Vec<PaneProxy>) - All panes in this tab (may be empty)
  • Err(ObjectError) - If navigation fails
pub fn active_pane<T>( &self, registry: &impl ObjectRegistry<T>, ) -> Result<PaneProxy>

Get active pane

This method returns the first pane in the tab. In a full implementation, this would query which pane is actually focused.

Arguments
  • registry - The object registry to use for navigation
Returns
  • Ok(PaneProxy) - The active pane in this tab
  • Err(ObjectError) - If the tab has no panes or navigation fails
pub fn activate(&self) -> Result<()>

Switch to this tab

pub fn is_active(&self) -> Result<bool>

Check if this tab is active

pub fn window<T>( &self, registry: &impl ObjectRegistry<T>, ) -> Result<WindowProxy>

Get parent window

Arguments
  • registry - The object registry to use for navigation
Returns
  • Ok(WindowProxy) - The window containing this tab
  • Err(ObjectError) - If the tab has no parent or navigation fails