pub struct ModalItem {
pub id: String,
pub label: String,
pub description: Option<String>,
}Fields
id: Stringlabel: Stringdescription: Option<String>Trait Implementations
Sourceimpl Archive for ModalItem
impl Archive for ModalItem
Sourcetype Archived = ArchivedModalItem
type Archived = ArchivedModalItem
The archived representation of this type. Read more
Sourcetype Resolver = ModalItemResolver
type Resolver = ModalItemResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.