pub struct OverlayStyle {
pub fg: u32,
pub bg: u32,
pub z_index: f32,
}Fields
fg: u32bg: u32z_index: f32Trait Implementations
Sourceimpl Archive for OverlayStyle
impl Archive for OverlayStyle
Sourcetype Archived = ArchivedOverlayStyle
type Archived = ArchivedOverlayStyle
The archived representation of this type. Read more
Sourcetype Resolver = OverlayStyleResolver
type Resolver = OverlayStyleResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for OverlayStyle
impl Clone for OverlayStyle
Sourcefn clone(&self) -> OverlayStyle
fn clone(&self) -> OverlayStyle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OverlayStyle
impl Debug for OverlayStyle
Sourceimpl Default for OverlayStyle
impl Default for OverlayStyle
Sourcefn default() -> OverlayStyle
fn default() -> OverlayStyle
Returns the “default value” for a type. Read more
Sourceimpl<__D> Deserialize<OverlayStyle, __D> for <OverlayStyle as Archive>::Archived
impl<__D> Deserialize<OverlayStyle, __D> for <OverlayStyle as Archive>::Archived
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<OverlayStyle, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<OverlayStyle, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for OverlayStyle
impl PartialEq for OverlayStyle
Sourceimpl<__S> Serialize<__S> for OverlayStyle
impl<__S> Serialize<__S> for OverlayStyle
impl Copy for OverlayStyle
impl StructuralPartialEq for OverlayStyle