Delightful messages, ASCII art, and celebrations for the plugin system
Making plugin development and usage more enjoyable, one message at a time.
Enums
- Achievement
- Achievement system for plugin milestones
- Plugin
Mood - Plugin mood indicator based on performance
Constants
- CONFETTI
- ASCII art for celebrations
- DEVELOPER_
TIPS - Tips and tricks for plugin developers
- ERROR_
PREFIXES - Friendly error message prefixes
- LOADING_
MESSAGES - Loading messages to show when plugins are being loaded
- PARTY_
POPPER - ROCKET
- SUCCESS_
MESSAGES - Success messages for plugin loading
- TROPHY
Functions
- celebration_
message - Format a celebration message for special occasions
- friendly_
error - Format a friendly error message with suggestions
- random_
developer_ tip - Get a random developer tip
- random_
error_ prefix - Get a random error prefix
- random_
loading_ message - Get a random loading message
- random_
success_ message - Get a random success message
- special_
date_ message - Check if today is a special date and return a message