pub struct TabProxy { /* private fields */ }Expand description
Proxy for a terminal tab
Implementations
Sourceimpl TabProxy
impl TabProxy
pub fn new(handle: ObjectHandle) -> Result<Self>
pub fn handle(&self) -> ObjectHandle
pub fn id(&self) -> u64
Sourcepub fn active_pane<T>(
&self,
registry: &impl ObjectRegistry<T>,
) -> Result<PaneProxy>
pub fn active_pane<T>( &self, registry: &impl ObjectRegistry<T>, ) -> Result<PaneProxy>
Get active pane
This method returns the first pane in the tab. In a full implementation, this would query which pane is actually focused.
Arguments
registry- The object registry to use for navigation
Returns
Ok(PaneProxy)- The active pane in this tabErr(ObjectError)- If the tab has no panes or navigation fails
Sourcepub fn window<T>(
&self,
registry: &impl ObjectRegistry<T>,
) -> Result<WindowProxy>
pub fn window<T>( &self, registry: &impl ObjectRegistry<T>, ) -> Result<WindowProxy>